@@ -1,11 +1,9 @@
 use super::ChangeSet;
+use crate::internal_prelude::*;
 use crate::{
     compile::{sass::compile_sass, tailwind::compile_tailwind},
     config::Project,
-    ext::{
-        anyhow::{anyhow, bail, Context, Result},
-        PathBufExt,
-    },
+    ext::{Paint, PathBufExt},
     fs,
     logger::GRAY,
     signal::{Outcome, Product},
@@ -28,28 +26,29 @@ pub async fn style(
     tokio::spawn(async move {
         let css_in_source = proj.style.tailwind.is_some();
         if !changes.need_style_build(true, css_in_source) {
-            log::debug!("Style no build needed {changes:?}");
+            debug!("Style no build needed {changes:?}");
             return Ok(Outcome::Success(Product::None));
         }
         build(&proj).await
     })
 }
+
 fn build_sass(proj: &Arc<Project>) -> JoinHandle<Result<Outcome<String>>> {
     let proj = proj.clone();
     tokio::spawn(async move {
         let Some(style_file) = &proj.style.file else {
-            log::trace!("Style not configured");
+            trace!("Style not configured");
             return Ok(Outcome::Success("".to_string()));
         };
 
-        log::trace!("Style found: {}", &style_file);
+        debug!("Style found: {}", &style_file);
         fs::create_dir_all(style_file.dest.clone().without_last())
             .await
             .dot()?;
         match style_file.source.extension() {
             Some("sass") | Some("scss") => compile_sass(style_file, proj.release)
                 .await
-                .context(format!("compile sass/scss: {}", &style_file)),
+                .wrap_err(format!("compile sass/scss: {}", &style_file)),
             Some("css") => Ok(Outcome::Success(
                 fs::read_to_string(&style_file.source).await.dot()?,
             )),
@@ -62,10 +61,10 @@ fn build_tailwind(proj: &Arc<Project>) -> JoinHandle<Result<Outcome<String>>> {
     let proj = proj.clone();
     tokio::spawn(async move {
         let Some(tw_conf) = proj.style.tailwind.as_ref() else {
-            log::trace!("Tailwind not configured");
+            trace!("Tailwind not configured");
             return Ok(Outcome::Success("".to_string()));
         };
-        log::trace!("Tailwind config: {:?}", &tw_conf);
+        trace!("Tailwind config: {:?}", &tw_conf);
         compile_tailwind(&proj, tw_conf).await
     })
 }
@@ -86,15 +85,15 @@ async fn build(proj: &Arc<Project>) -> Result<Outcome<Product>> {
 }
 
 fn browser_lists(query: &str) -> Result<Option<Browsers>> {
-    Browsers::from_browserslist([query]).context(format!("Error in browserlist query: {query}"))
+    Browsers::from_browserslist([query]).wrap_err(format!("Error in browserlist query: {query}"))
 }
 
 async fn process_css(proj: &Project, css: String) -> Result<Product> {
-    let browsers = browser_lists(&proj.style.browserquery).context("leptos.style.browserquery")?;
+    let browsers = browser_lists(&proj.style.browserquery).wrap_err("leptos.style.browserquery")?;
     let targets = Targets::from(browsers);
 
     let mut stylesheet =
-        StyleSheet::parse(&css, ParserOptions::default()).map_err(|e| anyhow!("{e}"))?;
+        StyleSheet::parse(&css, ParserOptions::default()).map_err(|e| eyre!("{e}"))?;
 
     if proj.release {
         let minify_options = MinifyOptions {
@@ -116,14 +115,14 @@ async fn process_css(proj: &Project, css: String) -> Result<Product> {
 
     let prod = match proj.site.updated_with(&proj.style.site_file, bytes).await? {
         true => {
-            log::trace!(
+            trace!(
                 "Style finished with changes {}",
                 GRAY.paint(proj.style.site_file.to_string())
             );
             Product::Style("".to_string()) //TODO
         }
         false => {
-            log::trace!("Style finished without changes");
+            trace!("Style finished without changes");
             Product::None
         }
     };
